pub trait Extension {
// Required method
fn extend<'life0, 'life1, 'async_trait>(
&'life0 mut self,
request: &'life1 (dyn TokenRequest + Sync),
) -> Pin<Box<dyn Future<Output = Result<Extensions, ()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
}Required Methods
Sourcefn extend<'life0, 'life1, 'async_trait>(
&'life0 mut self,
request: &'life1 (dyn TokenRequest + Sync),
) -> Pin<Box<dyn Future<Output = Result<Extensions, ()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn extend<'life0, 'life1, 'async_trait>(
&'life0 mut self,
request: &'life1 (dyn TokenRequest + Sync),
) -> Pin<Box<dyn Future<Output = Result<Extensions, ()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Inspect the request and extension data to produce extension data.
The input data comes from the extension data produced in the handling of the authorization code request.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".